@@ -1,30 +1,18 @@
 /*
- * Copyright (C) 2015 Dominik Haumann <dhaumann@kde.org>
+ * SPDX-FileCopyrightText: 2015 Dominik Haumann <dhaumann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #include "DiskQuota.h"
 #include "QuotaItem.h"
 #include "QuotaListModel.h"
 
-#include <KLocalizedString>
 #include <KFormat>
+#include <KLocalizedString>
 
-#include <QTimer>
 #include <QRegularExpression>
 #include <QStandardPaths>
+#include <QTimer>
 // #include <QDebug>
 
 DiskQuota::DiskQuota(QObject *parent)
@@ -36,8 +24,7 @@ DiskQuota::DiskQuota(QObject *parent)
     connect(m_timer, &QTimer::timeout, this, &DiskQuota::updateQuota);
     m_timer->start(2 * 60 * 1000); // check every 2 minutes
 
-    connect(m_quotaProcess, (void (QProcess::*)(int, QProcess::ExitStatus))&QProcess::finished,
-            this, &DiskQuota::quotaProcessFinished);
+    connect(m_quotaProcess, (void (QProcess::*)(int, QProcess::ExitStatus)) & QProcess::finished, this, &DiskQuota::quotaProcessFinished);
 
     updateQuota();
 }
@@ -155,14 +142,14 @@ static bool isQuotaLine(const QString &line)
 
 void DiskQuota::updateQuota()
 {
-    const bool quotaFound = ! QStandardPaths::findExecutable(QStringLiteral("quota")).isEmpty();
+    const bool quotaFound = !QStandardPaths::findExecutable(QStringLiteral("quota")).isEmpty();
     setQuotaInstalled(quotaFound);
     if (!quotaFound) {
         return;
     }
 
     // for now, only filelight is supported
-    setCleanUpToolInstalled(! QStandardPaths::findExecutable(QStringLiteral("filelight")).isEmpty());
+    setCleanUpToolInstalled(!QStandardPaths::findExecutable(QStringLiteral("filelight")).isEmpty());
 
     // kill running process in case it hanged for whatever reason
     if (m_quotaProcess->state() != QProcess::NotRunning) {
@@ -171,12 +158,12 @@ void DiskQuota::updateQuota()
 
     // Try to run 'quota'
     const QStringList args{
-        QStringLiteral("--show-mntpoint"),     // second entry is e.g. '/home'
-        QStringLiteral("--hide-device"),       // hide e.g. /dev/sda3
-        QStringLiteral("--no-mixed-pathnames"),// trim leading slashes from NFSv4 mountpoints
-        QStringLiteral("--all-nfs"),           // show all mount points
-        QStringLiteral("--no-wrap"),           // do not wrap long lines
-        QStringLiteral("--quiet-refuse"),      // no not print error message when NFS server does not respond
+        QStringLiteral("--show-mntpoint"), // second entry is e.g. '/home'
+        QStringLiteral("--hide-device"), // hide e.g. /dev/sda3
+        QStringLiteral("--no-mixed-pathnames"), // trim leading slashes from NFSv4 mountpoints
+        QStringLiteral("--all-nfs"), // show all mount points
+        QStringLiteral("--no-wrap"), // do not wrap long lines
+        QStringLiteral("--quiet-refuse"), // no not print error message when NFS server does not respond
     };
 
     m_quotaProcess->start(QStringLiteral("quota"), args, QIODevice::ReadOnly);
@@ -195,22 +182,18 @@ void DiskQuota::quotaProcessFinished(int exitCode, QProcess::ExitStatus exitStat
 
     // get quota output
     const QString rawData = QString::fromLocal8Bit(m_quotaProcess->readAllStandardOutput());
-//     qDebug() << rawData;
+    //     qDebug() << rawData;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList lines = rawData.split(QRegularExpression(QStringLiteral("[\r\n]")), QString::SkipEmptyParts);
-#else
     const QStringList lines = rawData.split(QRegularExpression(QStringLiteral("[\r\n]")), Qt::SkipEmptyParts);
-#endif
     // Testing
-//     QStringList lines = QStringList()
-//         << QStringLiteral("/home/peterpan 3975379*  5000000 7000000           57602 0       0")
-//         << QStringLiteral("/home/archive 2263536  6000000 5100000            3932 0       0")
-//         << QStringLiteral("/home/shared 4271196*  10000000 7000000           57602 0       0");
-//         << QStringLiteral("/home/peterpan %1*  5000000 7000000           57602 0       0").arg(qrand() % 5000000)
-//         << QStringLiteral("/home/archive %1  5000000 5100000            3932 0       0").arg(qrand() % 5000000)
-//         << QStringLiteral("/home/shared %1*  5000000 7000000           57602 0       0").arg(qrand() % 5000000);
-//     lines.removeAt(qrand() % lines.size());
+    //     QStringList lines = QStringList()
+    //         << QStringLiteral("/home/peterpan 3975379*  5000000 7000000           57602 0       0")
+    //         << QStringLiteral("/home/archive 2263536  6000000 5100000            3932 0       0")
+    //         << QStringLiteral("/home/shared 4271196*  10000000 7000000           57602 0       0");
+    //         << QStringLiteral("/home/peterpan %1*  5000000 7000000           57602 0       0").arg(qrand() % 5000000)
+    //         << QStringLiteral("/home/archive %1  5000000 5100000            3932 0       0").arg(qrand() % 5000000)
+    //         << QStringLiteral("/home/shared %1*  5000000 7000000           57602 0       0").arg(qrand() % 5000000);
+    //     lines.removeAt(qrand() % lines.size());
 
     // format class needed for GiB/MiB/KiB formatting
     KFormat fmt;
@@ -219,16 +202,12 @@ void DiskQuota::quotaProcessFinished(int exitCode, QProcess::ExitStatus exitStat
 
     // assumption: Filesystem starts with slash
     for (const QString &line : lines) {
-//         qDebug() << line << isQuotaLine(line);
+        //         qDebug() << line << isQuotaLine(line);
         if (!isQuotaLine(line)) {
             continue;
         }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QStringList parts = line.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
         QStringList parts = line.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
         // valid lines range from 7 to 9 parts (grace not always there):
         // Disk quotas for user dh (uid 1000):
         //      Filesystem   blocks  quota    limit     grace   files    quota   limit   grace
@@ -258,7 +237,7 @@ void DiskQuota::quotaProcessFinished(int exitCode, QProcess::ExitStatus exitStat
         item.setIconName(iconNameForQuota(percent));
         item.setMountPoint(parts[0]);
         item.setUsage(percent);
-        item.setMountString(i18nc("usage of quota, e.g.: '/home/bla: 38\% used'", "%1: %2% used", parts[0], percent));
+        item.setMountString(i18nc("usage of quota, e.g.: '/home/bla: 38% used'", "%1: %2% used", parts[0], percent));
         item.setUsedString(i18nc("e.g.: 12 GiB of 20 GiB", "%1 of %2", fmt.formatByteSize(used), fmt.formatByteSize(softLimit)));
         item.setFreeString(i18nc("e.g.: 8 GiB free", "%1 free", fmt.formatByteSize(qMax(qint64(0), freeSize))));
 
@@ -267,7 +246,7 @@ void DiskQuota::quotaProcessFinished(int exitCode, QProcess::ExitStatus exitStat
         maxQuota = qMax(maxQuota, percent);
     }
 
-//     qDebug() << "QUOTAS:" << quotas;
+    //     qDebug() << "QUOTAS:" << quotas;
 
     // make sure max quota is 100. Could be more, due to the
     // hard limit > soft limit, and we take soft limit as 100%
@@ -277,13 +256,10 @@ void DiskQuota::quotaProcessFinished(int exitCode, QProcess::ExitStatus exitStat
     setIconName(iconNameForQuota(maxQuota));
 
     // update status
-    setStatus(maxQuota < 50 ? PassiveStatus
-            : maxQuota < 98 ? ActiveStatus
-            : NeedsAttentionStatus);
+    setStatus(maxQuota < 50 ? PassiveStatus : maxQuota < 98 ? ActiveStatus : NeedsAttentionStatus);
 
     if (!items.isEmpty()) {
-        setToolTip(i18nc("example: Quota: 83% used",
-                         "Quota: %1% used", maxQuota));
+        setToolTip(i18nc("example: Quota: 83% used", "Quota: %1% used", maxQuota));
         setSubToolTip(QString());
     } else {
         setToolTip(i18n("Disk Quota"));
