@@ -1,31 +1,19 @@
 /*
- *   Copyright (C) 2007 Tobias Koenig <tokoe@kde.org>
+ *   SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-only
  */
 
 #include "cachedprovider.h"
 
+#include <QDebug>
 #include <QDir>
 #include <QFile>
-#include <QSettings>
-#include <QTimer>
 #include <QImage>
-#include <QDebug>
-#include <QUrl>
+#include <QSettings>
 #include <QStandardPaths>
+#include <QTimer>
+#include <QUrl>
 
 const int CachedProvider::CACHE_DEFAULT = 20;
 
@@ -36,11 +24,10 @@ static QString identifierToPath(const QString &identifier)
     return dataDir + QString::fromLatin1(QUrl::toPercentEncoding(identifier));
 }
 
-
 CachedProvider::CachedProvider(QObject *parent, const QVariantList &args)
     : ComicProvider(parent, args)
 {
-    QTimer::singleShot(0, this, SLOT(triggerFinished()));
+    QTimer::singleShot(0, this, &CachedProvider::triggerFinished);
 }
 
 CachedProvider::~CachedProvider()
@@ -54,8 +41,9 @@ ComicProvider::IdentifierType CachedProvider::identifierType() const
 
 QImage CachedProvider::image() const
 {
-    if (!QFile::exists(identifierToPath(requestedString())))
+    if (!QFile::exists(identifierToPath(requestedString()))) {
         return QImage();
+    }
 
     QImage img;
     img.load(identifierToPath(requestedString()), "PNG");
@@ -100,25 +88,25 @@ QString CachedProvider::comicAuthor() const
 
 QString CachedProvider::stripTitle() const
 {
-    QSettings settings(identifierToPath (requestedString()) + QLatin1String(".conf"), QSettings::IniFormat);
+    QSettings settings(identifierToPath(requestedString()) + QLatin1String(".conf"), QSettings::IniFormat);
     return settings.value(QLatin1String("stripTitle"), QString()).toString();
 }
 
 QString CachedProvider::additionalText() const
 {
-    QSettings settings(identifierToPath (requestedString()) + QLatin1String(".conf"), QSettings::IniFormat);
+    QSettings settings(identifierToPath(requestedString()) + QLatin1String(".conf"), QSettings::IniFormat);
     return settings.value(QLatin1String("additionalText"), QString()).toString();
 }
 
 QString CachedProvider::suffixType() const
 {
-    QSettings settings(identifierToPath (requestedComicName()) + QLatin1String(".conf"), QSettings::IniFormat);
+    QSettings settings(identifierToPath(requestedComicName()) + QLatin1String(".conf"), QSettings::IniFormat);
     return settings.value(QLatin1String("suffixType"), QString()).toString();
 }
 
 QString CachedProvider::name() const
 {
-    QSettings settings(identifierToPath (requestedComicName()) + QLatin1String(".conf"), QSettings::IniFormat);
+    QSettings settings(identifierToPath(requestedComicName()) + QLatin1String(".conf"), QSettings::IniFormat);
     return settings.value(QLatin1String("title"), QString()).toString();
 }
 
@@ -139,33 +127,34 @@ bool CachedProvider::storeInCache(const QString &identifier, const QImage &comic
     int index = identifier.indexOf(QLatin1Char(':'));
     const QString comicName = identifier.mid(0, index);
     const QString pathMain = identifierToPath(comicName);
-    const QString dirPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/plasma_engine_comic/") ;
+    const QString dirPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/plasma_engine_comic/");
 
     if (!info.isEmpty()) {
         QSettings settings(path + QLatin1String(".conf"), QSettings::IniFormat);
         QSettings settingsMain(pathMain + QLatin1String(".conf"), QSettings::IniFormat);
 
         for (Settings::const_iterator i = info.constBegin(); i != info.constEnd(); ++i) {
-                if ((i.key() == QLatin1String("firstStripIdentifier")) || (i.key() == QLatin1String("title")) ||
-                     (i.key() == QLatin1String("lastCachedStripIdentifier")) || (i.key() == QLatin1String("suffixType")) ||
-                     (i.key() == QLatin1String("shopUrl")) || (i.key() == QLatin1String("isLeftToRight")) ||
-                     (i.key() == QLatin1String("isTopToBottom"))) {
-                    settingsMain.setValue(i.key(), i.value());
-                } else {
-                    settings.setValue(i.key(), i.value());
-                }
+            if ((i.key() == QLatin1String("firstStripIdentifier")) || (i.key() == QLatin1String("title"))
+                || (i.key() == QLatin1String("lastCachedStripIdentifier")) || (i.key() == QLatin1String("suffixType")) || (i.key() == QLatin1String("shopUrl"))
+                || (i.key() == QLatin1String("isLeftToRight")) || (i.key() == QLatin1String("isTopToBottom"))) {
+                settingsMain.setValue(i.key(), i.value());
+            } else {
+                settings.setValue(i.key(), i.value());
+            }
         }
 
         QStringList comics;
         if (settingsMain.contains(QLatin1String("comics"))) {
             comics = settingsMain.value(QLatin1String("comics"), QStringList()).toStringList();
         } else {
-            //existing strips haven't been stored in the conf-file yet, do that now, oldest first, newest last
+            // existing strips haven't been stored in the conf-file yet, do that now, oldest first, newest last
             QDir dir(dirPath);
-            comics = dir.entryList(QStringList() << QString::fromLatin1(QUrl::toPercentEncoding(comicName + QLatin1Char(':'))) + QLatin1Char('*'), QDir::Files, QDir::Time | QDir::Reversed);
+            comics = dir.entryList(QStringList() << QString::fromLatin1(QUrl::toPercentEncoding(comicName + QLatin1Char(':'))) + QLatin1Char('*'),
+                                   QDir::Files,
+                                   QDir::Time | QDir::Reversed);
             QStringList::iterator it = comics.begin();
             while (it != comics.end()) {
-                //only count images, not the conf files
+                // only count images, not the conf files
                 if ((*it).endsWith(QLatin1String(".conf"))) {
                     it = comics.erase(it);
                 } else {
@@ -176,7 +165,7 @@ bool CachedProvider::storeInCache(const QString &identifier, const QImage &comic
         comics.append(QString::fromLatin1(QUrl::toPercentEncoding(identifier)));
 
         const int limit = CachedProvider::maxComicLimit();
-        //limit is on
+        // limit is on
         if (limit > 0) {
             qDebug() << QLatin1String("MaxComicLimit on.");
             int comicsToRemove = comics.count() - limit;
@@ -186,7 +175,7 @@ bool CachedProvider::storeInCache(const QString &identifier, const QImage &comic
                 QFile::remove(dirPath + (*it));
                 QFile::remove(dirPath + (*it) + QLatin1String(".conf"));
                 it = comics.erase(it);
-                -- comicsToRemove;
+                --comicsToRemove;
             }
         }
         settingsMain.setValue(QLatin1String("comics"), comics);
@@ -228,7 +217,7 @@ bool CachedProvider::isTopToBottom() const
 int CachedProvider::maxComicLimit()
 {
     QSettings settings(identifierToPath(QLatin1String("comic_settings.conf")), QSettings::IniFormat);
-    return  qMax(settings.value(QLatin1String("maxComics"), CACHE_DEFAULT).toInt(), 0);//old value was -1, thus use qMax
+    return qMax(settings.value(QLatin1String("maxComics"), CACHE_DEFAULT).toInt(), 0); // old value was -1, thus use qMax
 }
 
 void CachedProvider::setMaxComicLimit(int limit)
@@ -240,4 +229,3 @@ void CachedProvider::setMaxComicLimit(int limit)
     QSettings settings(identifierToPath(QLatin1String("comic_settings.conf")), QSettings::IniFormat);
     settings.setValue(QLatin1String("maxComics"), limit);
 }
-
