@@ -1,134 +1,109 @@
 /*
- *   Copyright (C) 2007 Tobias Koenig <tokoe@kde.org>
+ *   SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-only
  */
 
 #include "comicprovider.h"
 
+#include <QDebug>
 #include <QTimer>
 #include <QUrl>
-#include <QDebug>
 
 #include <KIO/Job>
 #include <KIO/StoredTransferJob>
-#include <KPluginMetaData>
 
 class ComicProvider::Private
 {
-    public:
-        Private(const KPluginMetaData &data, ComicProvider *parent)
-            : mParent(parent),
-              mIsCurrent(false),
-              mFirstStripNumber(1),
-              mComicDescription(data)
-        {
-            mTimer = new QTimer(parent);
-            mTimer->setSingleShot(true);
-            mTimer->setInterval(15000);//timeout after 15 seconds
-            connect(mTimer, SIGNAL(timeout()), mParent, SLOT(slotTimeout()));
+public:
+    Private(const KPluginMetaData &data, ComicProvider *parent)
+        : mParent(parent)
+        , mIsCurrent(false)
+        , mFirstStripNumber(1)
+        , mComicDescription(data)
+    {
+        mTimer = new QTimer(parent);
+        mTimer->setSingleShot(true);
+        mTimer->setInterval(15000); // timeout after 15 seconds
+        connect(mTimer, &QTimer::timeout, mParent, [this]() {
+            // operation took too long, abort it
+            emit mParent->error(mParent);
+        });
+    }
+
+    void jobDone(KJob *job)
+    {
+        if (job->error()) {
+            mParent->pageError(job->property("uid").toInt(), job->errorText());
+        } else {
+            KIO::StoredTransferJob *storedJob = qobject_cast<KIO::StoredTransferJob *>(job);
+            mParent->pageRetrieved(job->property("uid").toInt(), storedJob->data());
+        }
+    }
+
+    void slotRedirection(KIO::Job *job, const QUrl &oldUrl, const QUrl &newUrl)
+    {
+        Q_UNUSED(oldUrl)
+
+        mParent->redirected(job->property("uid").toInt(), newUrl);
+        mRedirections.remove(job);
+    }
+
+    void slotRedirectionDone(KJob *job)
+    {
+        if (job->error()) {
+            qDebug() << "Redirection job with id" << job->property("uid").toInt() << "finished with an error.";
         }
 
-        void jobDone(KJob *job)
-        {
-            if (job->error()) {
-                mParent->pageError(job->property("uid").toInt(), job->errorText());
-            } else {
-                KIO::StoredTransferJob *storedJob = qobject_cast<KIO::StoredTransferJob*>(job);
-                mParent->pageRetrieved(job->property("uid").toInt(), storedJob->data());
-            }
-        }
-
-        void slotRedirection(KIO::Job *job, QUrl newUrl)
-        {
-            slotRedirection(job, QUrl(), newUrl);
-        }
-
-        void slotRedirection(KIO::Job *job, QUrl oldUrl, QUrl newUrl)
-        {
-            Q_UNUSED(oldUrl)
-
-            mParent->redirected(job->property("uid").toInt(), newUrl);
+        if (mRedirections.contains(job)) {
+            // no redirection took place, return the original url
+            mParent->redirected(job->property("uid").toInt(), mRedirections[job]);
             mRedirections.remove(job);
         }
+    }
 
-        void slotRedirectionDone(KJob *job)
-        {
-            if (job->error()) {
-                qDebug() << "Redirection job with id" << job->property("uid").toInt() <<  "finished with an error.";
-            }
-
-            if (mRedirections.contains(job)) {
-                //no redirection took place, return the original url
-                mParent->redirected(job->property("uid").toInt(), mRedirections[job]);
-                mRedirections.remove(job);
-            }
-        }
-
-        void slotTimeout()
-        {
-            //operation took too long, abort it
-            emit mParent->error(mParent);
-        }
-
-        void slotFinished()
-        {
-            //everything finished, stop the timeout timer
-            mTimer->stop();
-        }
-
-        ComicProvider *mParent;
-        QString mRequestedId;
-        QString mRequestedComicName;
-        QString mComicAuthor;
-        QUrl mImageUrl;
-        bool mIsCurrent;
-        bool mIsLeftToRight;
-        bool mIsTopToBottom;
-        QDate mRequestedDate;
-        QDate mFirstStripDate;
-        int mRequestedNumber;
-        int mFirstStripNumber;
-        KPluginMetaData mComicDescription;
-        QTimer *mTimer;
-        QHash< KJob*, QUrl > mRedirections;
+    ComicProvider *mParent;
+    QString mRequestedId;
+    QString mRequestedComicName;
+    QString mComicAuthor;
+    QUrl mImageUrl;
+    bool mIsCurrent;
+    bool mIsLeftToRight;
+    bool mIsTopToBottom;
+    QDate mRequestedDate;
+    QDate mFirstStripDate;
+    int mRequestedNumber;
+    int mFirstStripNumber;
+    KPluginMetaData mComicDescription;
+    QTimer *mTimer;
+    QHash<KJob *, QUrl> mRedirections;
 };
 
 ComicProvider::ComicProvider(QObject *parent, const QVariantList &args)
-    : QObject(parent), d(new Private(
-      KPluginMetaData(args.count() > 2 ? args[2].toString() : QString()), this))
+    : QObject(parent)
+    , d(new Private(KPluginMetaData(args.count() > 2 ? args[2].toString() : QString()), this))
 {
     Q_ASSERT(args.count() >= 2);
     const QString type = args[0].toString();
 
-    if (type == QLatin1String("Date"))
+    if (type == QLatin1String("Date")) {
         d->mRequestedDate = args[1].toDate();
-    else if (type == QLatin1String("Number"))
+    } else if (type == QLatin1String("Number")) {
         d->mRequestedNumber = args[1].toInt();
-    else if (type == QLatin1String("String")) {
+    } else if (type == QLatin1String("String")) {
         d->mRequestedId = args[1].toString();
 
         int index = d->mRequestedId.indexOf(QLatin1Char(':'));
         d->mRequestedComicName = d->mRequestedId.mid(0, index);
-    }
-    else {
+    } else {
         Q_ASSERT(false && "Invalid type passed to comic provider");
     }
 
     d->mTimer->start();
-    connect(this, SIGNAL(finished(ComicProvider*)), this, SLOT(slotFinished()));
+    connect(this, &ComicProvider::finished, this, [this]() {
+        // everything finished, stop the timeout timer
+        d->mTimer->stop();
+    });
 }
 
 ComicProvider::~ComicProvider()
@@ -138,16 +113,18 @@ ComicProvider::~ComicProvider()
 
 QString ComicProvider::nextIdentifier() const
 {
-    if (identifierType() == DateIdentifier && d->mRequestedDate != QDate::currentDate())
+    if (identifierType() == DateIdentifier && d->mRequestedDate != QDate::currentDate()) {
         return d->mRequestedDate.addDays(1).toString(Qt::ISODate);
+    }
 
     return QString();
 }
 
 QString ComicProvider::previousIdentifier() const
 {
-    if ((identifierType() == DateIdentifier) && (!firstStripDate().isValid() || d->mRequestedDate > firstStripDate()))
+    if ((identifierType() == DateIdentifier) && (!firstStripDate().isValid() || d->mRequestedDate > firstStripDate())) {
         return d->mRequestedDate.addDays(-1).toString(Qt::ISODate);
+    }
 
     return QString();
 }
@@ -235,7 +212,7 @@ QString ComicProvider::requestedComicName() const
 
 void ComicProvider::requestPage(const QUrl &url, int id, const MetaInfos &infos)
 {
-    //each request restarts the timer
+    // each request restarts the timer
     d->mTimer->start();
 
     if (id == Image) {
@@ -244,14 +221,16 @@ void ComicProvider::requestPage(const QUrl &url, int id, const MetaInfos &infos)
 
     KIO::StoredTransferJob *job;
     if (id == Image) {
-        //use cached information for the image if available
+        // use cached information for the image if available
         job = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
     } else {
-        //for webpages we always reload, making sure, that changes are recognised
+        // for webpages we always reload, making sure, that changes are recognised
         job = KIO::storedGet(url, KIO::Reload, KIO::HideProgressInfo);
     }
     job->setProperty("uid", id);
-    connect(job, SIGNAL(result(KJob*)), this, SLOT(jobDone(KJob*)));
+    connect(job, &KJob::result, this, [this](KJob *job) {
+        d->jobDone(job);
+    });
 
     if (!infos.isEmpty()) {
         QMapIterator<QString, QString> it(infos);
@@ -264,15 +243,21 @@ void ComicProvider::requestPage(const QUrl &url, int id, const MetaInfos &infos)
 
 void ComicProvider::requestRedirectedUrl(const QUrl &url, int id, const MetaInfos &infos)
 {
-    //each request restarts the timer
+    // each request restarts the timer
     d->mTimer->start();
 
     KIO::MimetypeJob *job = KIO::mimetype(url, KIO::HideProgressInfo);
     job->setProperty("uid", id);
     d->mRedirections[job] = url;
-    connect(job, SIGNAL(redirection(KIO::Job*,QUrl)), this, SLOT(slotRedirection(KIO::Job*,QUrl)));
-    connect(job, SIGNAL(permanentRedirection(KIO::Job*,QUrl,QUrl)), this, SLOT(slotRedirection(KIO::Job*,QUrl,QUrl)));
-    connect(job, SIGNAL(result(KJob*)), this, SLOT(slotRedirectionDone(KJob*)));
+    connect(job, &KIO::MimetypeJob::redirection, this, [this](KIO::Job *job, const QUrl &newUrl) {
+        d->slotRedirection(job, QUrl(), newUrl);
+    });
+    connect(job, &KIO::MimetypeJob::permanentRedirection, this, [this](KIO::Job *job, const QUrl &oldUrl, const QUrl &newUrl) {
+        d->slotRedirection(job, oldUrl, newUrl);
+    });
+    connect(job, &KIO::MimetypeJob::result, this, [this](KJob *job) {
+        d->slotRedirectionDone(job);
+    });
 
     if (!infos.isEmpty()) {
         QMapIterator<QString, QString> it(infos);
@@ -283,15 +268,15 @@ void ComicProvider::requestRedirectedUrl(const QUrl &url, int id, const MetaInfo
     }
 }
 
-void ComicProvider::pageRetrieved(int, const QByteArray&)
+void ComicProvider::pageRetrieved(int, const QByteArray &)
 {
 }
 
-void ComicProvider::pageError(int, const QString&)
+void ComicProvider::pageError(int, const QString &)
 {
 }
 
-void ComicProvider::redirected(int, const QUrl&)
+void ComicProvider::redirected(int, const QUrl &)
 {
 }
 
